[![Pyqrlew](https://github.com/Qrlew/pyqrlew/actions/workflows/ci.yml/badge.svg)](https://github.com/Qrlew/pyqrlew/actions)
![PyPI](https://img.shields.io/pypi/v/pyqrlew)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyqrlew)
![Discord](https://img.shields.io/discord/1194338163989172364?logo=Discord)
![X (formerly Twitter) Follow](https://img.shields.io/twitter/follow/sarus_tech)
# [Pyqrlew](https://pyqrlew.github.io/) Python bindings library (by [Sarus](https://www.sarus.tech/))

[Pyqrlew](https://pypi.org/project/pyqrlew/) is documented [here](https://pyqrlew.readthedocs.io/en/latest/)

Read the general [Qrlew](https://qrlew.github.io/) documentation on [qrlew.readthedocs.io](https://qrlew.readthedocs.io/en/latest/).

Learn more about [Sarus Technologies](https://sarus.tech/).